@@ -28,6 +28,7 @@ import polars as pl
 from tqdm.auto import tqdm
 
 from pymovements.base import Experiment
+from pymovements.events.events import Event
 from pymovements.events.events import EventDetectionCallable
 from pymovements.utils.paths import get_filepaths
 
@@ -120,7 +121,7 @@ class Dataset:
         AttributeError
             If no regular expression for parsing filenames is defined.
         RuntimeError
-            If an error occured during matching filenames.
+            If an error occured during matching filenames or no files have been found.
         """
         if self._filename_regex is not None:
             filename_regex = re.compile(self._filename_regex)
@@ -134,7 +135,7 @@ class Dataset:
         )
 
         # Parse fileinfo from filenames.
-        fileinfo_records: list[dict[str, Any]] = []
+        fileinfo_dicts: list[dict[str, Any]] = []
         for filepath in csv_filepaths:
 
             # All csv_filepaths already match the filename_regex.
@@ -147,16 +148,19 @@ class Dataset:
                 )
 
             # We use the groupdict of the match as a base and add the filepath.
-            fileinfo_record = match.groupdict()
+            fileinfo_dict = match.groupdict()
 
             for fileinfo_key, fileinfo_dtype in self._filename_regex_dtypes.items():
-                fileinfo_record[fileinfo_key] = fileinfo_dtype(fileinfo_record[fileinfo_key])
+                fileinfo_dict[fileinfo_key] = fileinfo_dtype(fileinfo_dict[fileinfo_key])
 
-            fileinfo_record['filepath'] = str(filepath)
-            fileinfo_records.append(fileinfo_record)
+            fileinfo_dict['filepath'] = str(filepath)
+            fileinfo_dicts.append(fileinfo_dict)
+
+        if len(fileinfo_dicts) == 0:
+            raise RuntimeError('no matching files found')
 
         # Create dataframe from all fileinfo records.
-        fileinfo_df = pl.from_dicts(dicts=fileinfo_records, infer_schema_length=1)
+        fileinfo_df = pl.from_dicts(dicts=fileinfo_dicts, infer_schema_length=1)
         fileinfo_df = fileinfo_df.sort(by='filepath')
 
         return fileinfo_df
@@ -394,6 +398,7 @@ class Dataset:
             self,
             method: EventDetectionCallable,
             eye: str = 'auto',
+            clear: bool = False,
             verbose: bool = True,
             **kwargs,
     ) -> None:
@@ -407,6 +412,9 @@ class Dataset:
             Select which eye to choose. Valid options are ``auto``, ``left`` or ``right``. If
             ``auto`` is passed, ``left`` will only be chosen if the right eye is not available in
             the gaze data frame.
+        clear : bool
+            If ``True``, event DataFrame will be overwritten with new DataFrame instead of being
+             merged into the existing one.
         verbose : bool
             If ``True``, show progress bar.
         **kwargs :
@@ -447,7 +455,7 @@ class Dataset:
             events = method(positions=positions, velocities=velocities, **kwargs)
             event_dfs.append(events)
 
-        if not self.events:
+        if not self.events or clear:
             self.events = event_dfs
             return
 
@@ -457,6 +465,14 @@ class Dataset:
                 how='diagonal',
             )
 
+    def clear_events(self) -> None:
+        """Clear event DataFrame."""
+        if len(self.events) == 0:
+            return
+
+        for file_id, _ in enumerate(self.events):
+            self.events[file_id] = pl.DataFrame(schema=Event.schema)
+
     def save(self, verbose: int = 1):
         """Save preprocessed gaze and event files.
 
